@@ -72,7 +72,13 @@ simple_re_match ( simple_re* re , const char* str , simple_re** pptr_for_last_re
 
 	OnigRegexType* regexp = re->regexp;
 	UChar* text =  re->str;
-	const UChar* end_ptr = re->str + strlen(re->str) ;
+	unsigned int len , idx; // Here, what this code does is same as strlen(text)
+	idx = 0;
+	while( text[idx] != '\0'){
+		idx = idx + 1;
+	}
+    len = idx; 
+	const UChar* end_ptr = re->str + len ;
 	const UChar* start_ptr = re->str ;
 	OnigRegion* region = re->matched ; 
 
@@ -107,8 +113,6 @@ simple_re_matched_str( simple_re* re , int idx )
 {
 	OnigRegion* matched;
 	int num_groups;
-	int start;
-	int end;
 	int length;
 	char* matched_str;
 	char* new_str;
